@@ -739,70 +739,6 @@ def build_set(
         sys.exit(1)
 
 
-DEVICES = [
-    "fvp-morello-android",
-    "fvp-morello-busybox",
-    "fvp-morello-oe",
-    "fvp-morello-ubuntu",
-    "qemu-arm",
-    "qemu-armv5",
-    "qemu-armv7",
-    "qemu-armv7be",
-    "qemu-arm64",
-    "qemu-arm64be",
-    "qemu-i386",
-    "qemu-mips",
-    "qemu-mips32",
-    "qemu-mips32el",
-    "qemu-mips64",
-    "qemu-mips64el",
-    "qemu-mipsel",
-    "qemu-powerpc",
-    "qemu-ppc32",
-    "qemu-ppc64",
-    "qemu-ppc64le",
-    "qemu-riscv",
-    "qemu-riscv64",
-    "qemu-s390",
-    "qemu-sh4",
-    "qemu-sparc64",
-    "qemu-x86_64",
-]
-TESTS = [
-    "binder",
-    "bionic",
-    "boringssl",
-    "boot",
-    "boottest",
-    "compartment",
-    "device-tree",
-    "dvfs",
-    "fwts",
-    "kselftest-gpio",
-    "kselftest-ipc",
-    "kselftest-ir",
-    "kselftest-kcmp",
-    "kselftest-kexec",
-    "kselftest-rseq",
-    "kselftest-rtc",
-    "kunit",
-    "lldb",
-    "libjpeg-turbo",
-    "libpdfium",
-    "libpng",
-    "logd",
-    "purecap",
-    "multicore",
-    "ltp-fcntl-locktests",
-    "ltp-fs_bind",
-    "ltp-fs_perms_simple",
-    "ltp-fsx",
-    "ltp-nptl",
-    "ltp-smoke",
-    "zlib",
-]
-
-
 def test_options(required):
     def option(*args, **kwargs):
         kw = kwargs.copy()
@@ -816,7 +752,7 @@ def test_options(required):
         option(
             "--device",
             help="Device type",
-            type=click.Choice(DEVICES),
+            type=str,
         ),
         option(
             "--kernel",
@@ -868,6 +804,13 @@ def test_options(required):
             help="Comma separated list of tests",
             default="boot",
         ),
+        option(
+            "--timeouts",
+            help="timeouts as KEY=VALUE",
+            default=[],
+            type=str,
+            multiple=True,
+        ),
         option(
             "--boot-args",
             help="Extra boot arguments",
@@ -947,6 +890,7 @@ def test(
     scp_romfw,
     fip,
     tests,
+    timeouts,
     boot_args,
     wait_for,
     no_wait,
@@ -974,13 +918,6 @@ def test(
         raise click.exceptions.UsageError(error_message)
 
     tests = [test for test in tests.split(",") if test]
-    invalid_tests = [test for test in tests if test not in TESTS]
-    if invalid_tests:
-        raise click.ClickException(
-            "Invalid tests [{}], only valid tests are: [{}]".format(
-                ", ".join(invalid_tests), ", ".join(TESTS)
-            )
-        )
     tests = [test for test in tests if test != "boot"]
     if wait_for:
         info(
@@ -1006,6 +943,11 @@ def test(
         k, v = p.split("=")
         params[k] = v
 
+    timeouts_d = {}
+    for t in timeouts:
+        k, v = t.split("=")
+        timeouts_d[k] = int(v)
+
     try:
         test = tuxsuite.Test(
             device=device,
@@ -1020,6 +962,7 @@ def test(
             fip=fip,
             parameters=params,
             tests=tests,
+            timeouts=timeouts_d,
             boot_args=boot_args,
             wait_for=wait_for,
         )
